# -*- coding: utf-8 -*-
import os
import sys
import requests
import re
import xbmcvfs

class EweTv():
    def __init__(self, username, password):
        self.baseUrl = 'https://tvonline.ewe.de'
        self.session = requests.Session()
        self.session.headers["User-Agent"] = 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/48.0.2564.116 Safari/537.36'
        self.username = username
        self.password = password
        self.account_data = None
        self.current_channel_id = ''

    def fetchappToken(self):
        r = self.session.get(self.baseUrl)
        html = r.text
        return re.search("window\.appToken\s*=\s*'(.*)'", html).group(1)

    def announce(self):
        url = self.baseUrl + '/zapi/v2/session/hello'        
        params = {"client_app_token" : self.fetchappToken(),
                  "uuid"    : "608e1694-11fa-4424-9607-ad49b227f245",
                  "lang"    : "de",
                  "app_version": "2.0.4",
                  "format"	: "json"}
        r = self.session.post(url, data=params, verify=False)

    def login(self):
        self.announce()
        url = 'https://tvonline.ewe.de/zapi/v2/account/login'
        headers = self.session.headers
        headers["Content-Type"] = "application/x-www-form-urlencoded; charset=UTF-8"
        payload = {'login': self.username, 'password': self.password, 'remember': 'false'}
        r = self.session.post(url, data=payload, headers=headers, verify=False)
        data = r.json()
        print data
        if data['success']:
            self.account_data = data
            return True

        return False

    def getChannelUrl(self):
        url = self.baseUrl + '/zapi/watch'
        headers = self.session.headers
        headers["Content-Type"] = "application/x-www-form-urlencoded; charset=UTF-8"
        params = {'cid': self.current_channel_id, 'stream_type': 'hls'}
        r = self.session.post(url, data=params, headers=headers, verify=False)
        return r.json()["stream"]["url"]

    def getChannelList(self):
        url = self.baseUrl + '/zapi/v2/cached/channels/' + self.account_data['session']['power_guide_hash'] + '?details=False'
        headers = self.session.headers
        r = self.session.get(url, headers=headers, verify=False)
        data = r.json()
        if data['success']:
            return data

        return None

    def generateM3U(self, path, host, port):
        channels = self.getChannelList()
        if not channels:
            return False

        m3u_lines = []
        has_changed = False

        if xbmcvfs.exists(path):
            f = xbmcvfs.File(path, 'r')
            m3u_lines = f.read().split('\n')
            f.close()            

        for group in channels['channel_groups']:
            for c in group['channels']:
                line = ('#EXTINF:-1 tvg-id=%s.de tvg-logo=%s.de tvg-name=%s, %s' % (c['title'].replace(' ', ''), c['title'].replace(' ', ''), c['title'].replace(' ', '_'), c['title'])).encode('utf8')
                line2 = ('http://' + host + ':' + str(port) + '/channel.m3u8?channel_id=' + c['cid']).encode('utf8')
                if not line in m3u_lines and not line2 in m3u_lines:
                    m3u_lines.append(line)
                    m3u_lines.append(line2)
                    has_changed = True

        if has_changed:
            f = xbmcvfs.File(path, 'w+')
            if not m3u_lines[0].startswith('#EXTM3U'):
                f.write('#EXTM3U\n')
            for item in m3u_lines:
                if not item == '':
                    f.write(item + '\n')
            f.close()

        del m3u_lines[:]
        return has_changed

